@@ -30,6 +30,9 @@
 #include "ev-transition-animation.h"
 #include "ev-view-cursor.h"
 #include "ev-page-cache.h"
+#ifdef GDK_WINDOWING_WAYLAND
+#include <gdk/gdkwayland.h>
+#endif
 
 enum {
 	PROP_0,
@@ -1287,14 +1290,16 @@ ev_view_presentation_update_monitor_geometry (EvViewPresentation *pview)
 	monitor = gdk_display_get_monitor_at_window (display, window);
 	gdk_monitor_get_geometry (monitor, &geometry);
 
-#if GTK_CHECK_VERSION(3, 24, 9)
-	/* See Evince issue #1365 and GTK regression gtk#2599 */
-	int scale_factor = gdk_monitor_get_scale_factor (monitor);
-	pview->monitor_width = geometry.width / scale_factor;
-	pview->monitor_height = geometry.height / scale_factor;
-#else
 	pview->monitor_width = geometry.width;
 	pview->monitor_height = geometry.height;
+
+#if GTK_CHECK_VERSION(3, 24, 9) && defined (GDK_WINDOWING_WAYLAND)
+	if (GDK_IS_WAYLAND_DISPLAY (display)) {
+		/* See Evince issue #1365 and GTK regression gtk#2599 */
+		int scale_factor = gdk_monitor_get_scale_factor (monitor);
+		pview->monitor_width = geometry.width / scale_factor;
+		pview->monitor_height = geometry.height / scale_factor;
+	}
 #endif
 }
 
