@@ -95,7 +95,7 @@ ev_annotation_properties_dialog_constructed (GObject *object)
 	switch (dialog->annot_type) {
 	case EV_ANNOTATION_TYPE_TEXT:
 		label = gtk_label_new (_("Icon:"));
-		gtk_misc_set_alignment (GTK_MISC (label), 0., 0.5);
+		g_object_set (G_OBJECT (label), "xalign", 0., "yalign", 0.5, NULL);
 		gtk_grid_attach (GTK_GRID (grid), label, 0, 4, 1, 1);
 		gtk_widget_show (label);
 
@@ -121,7 +121,7 @@ ev_annotation_properties_dialog_constructed (GObject *object)
                 break;
         case EV_ANNOTATION_TYPE_TEXT_MARKUP:
                 label = gtk_label_new (_("Markup type:"));
-                gtk_misc_set_alignment (GTK_MISC (label), 0., 0.5);
+                g_object_set (G_OBJECT (label), "xalign", 0., "yalign", 0.5, NULL);
                 gtk_grid_attach (GTK_GRID (grid), label, 0, 5, 1, 1);
                 gtk_widget_show (label);
 
@@ -153,8 +153,8 @@ ev_annotation_properties_dialog_init (EvAnnotationPropertiesDialog *annot_dialog
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (annot_dialog), TRUE);
 	gtk_container_set_border_width (GTK_CONTAINER (annot_dialog), 5);
 	gtk_dialog_add_buttons (dialog,
-				GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-				GTK_STOCK_APPLY, GTK_RESPONSE_APPLY,
+				_("_Close"), GTK_RESPONSE_CLOSE,
+				_("_Apply"), GTK_RESPONSE_APPLY,
 				NULL);
 	gtk_dialog_set_default_response (dialog, GTK_RESPONSE_APPLY);
 
@@ -169,7 +169,7 @@ ev_annotation_properties_dialog_init (EvAnnotationPropertiesDialog *annot_dialog
 	gtk_widget_show (grid);
 
 	label = gtk_label_new (_("Author:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0., 0.5);
+	g_object_set (G_OBJECT (label), "xalign", 0., "yalign", 0.5, NULL);
 	gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1, 1);
 	gtk_widget_show (label);
 
@@ -180,7 +180,7 @@ ev_annotation_properties_dialog_init (EvAnnotationPropertiesDialog *annot_dialog
 	gtk_widget_show (annot_dialog->author);
 
 	label = gtk_label_new (_("Color:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0., 0.5);
+	g_object_set (G_OBJECT (label), "xalign", 0., "yalign", 0.5, NULL);
 	gtk_grid_attach (GTK_GRID (grid), label, 0, 1, 1, 1);
 	gtk_widget_show (label);
 
@@ -190,7 +190,7 @@ ev_annotation_properties_dialog_init (EvAnnotationPropertiesDialog *annot_dialog
 	gtk_widget_show (annot_dialog->color);
 
 	label = gtk_label_new (_("Opacity:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0., 0.5);
+	g_object_set (G_OBJECT (label), "xalign", 0., "yalign", 0.5, NULL);
 	gtk_grid_attach (GTK_GRID (grid), label, 0, 2, 1, 1);
 	gtk_widget_show (label);
 
@@ -202,7 +202,7 @@ ev_annotation_properties_dialog_init (EvAnnotationPropertiesDialog *annot_dialog
 	gtk_widget_show (annot_dialog->opacity);
 
 	label = gtk_label_new (_("Initial window state:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0., 0.5);
+	g_object_set (G_OBJECT (label), "xalign", 0., "yalign", 0.5, NULL);
 	gtk_grid_attach (GTK_GRID (grid), label, 0, 3, 1, 1);
 	gtk_widget_show (label);
 
